/* 
   TUXCNC GPL
   Digital charge pump with differential output for ATtiny13
   Toggle outputs at about 576 Hz with 9,6 MHz clock, watch out for this frequency - module will unstable.  
   Input PB1, outputs PB3 and PB4
*/

#include <avr/io.h> 
#include <avr/interrupt.h>
  
volatile uint8_t index = 0;
volatile uint8_t ignored = 100; // number of impulses ignored before change outputs
   
int main(void)
{
  DDRB |= (1 << PB3) | (1 << PB4); //set output pins
  PORTB |= (1<<PB1); // Enable input pull-up on INT0
  
  MCUCR |=  ((1<<ISC00) | (1<<ISC01));	// Trigger INT0 on rising edge
  GIMSK |= (1<<INT0); // enable INT0 interrupt
  
  TCCR0A = 0x00;   // Timer0 normal mode
  TCCR0B |= (1<<CS00)|(1<<CS01);  // prescaler /64
  TIMSK0 |= (1<<TOIE0); // enable Timer0 interrupt
  SREG |= 0b10000000; //  enable global interrupt
  while(1){
    if (index == ignored){
    PORTB |= (1<<PB3);
    PORTB &= ~(1<<PB4);
    }
    else{
    PORTB &= ~(1<<PB3);
    PORTB |= (1<<PB4);
    }
  } // endless loop
}

ISR(TIM0_OVF_vect)   // Timer0 overload interrupt handler  
{
    index = 0; // not enough impulses - count again
}   

ISR(INT0_vect) // External interrupt handler 
{
    TCNT0=0; // reset watchdog
    if (index < ignored) index++; // count impulses if less than enought
}
